@@ -93,23 +93,37 @@ MultipleResponseVariable <-setClass("MultipleResponseVariable",
 ##' more generally, this field can be referenced as "name" as well.
 ##' @slot entities a character vector of variable URLs, or a list containing a
 ##' combination of variable URLs and VariableGroup objects.
+##' @slot duplicates logical: should duplicate variable references be allowed in
+##' this object? Default is \code{FALSE}.
+##' @slot vars either \code{NULL} or a \code{\link{VariableCatalog}}. If not
+##' \code{NULL}, it will be used to look up variable names from the URLs.
 ##' @rdname VariableOrder
 ##' @export VariableOrder
 VariableOrder <- setClass("VariableOrder", contains="ShojiOrder",
     representation=representation(
-        vars="ANY"
+        vars="ANY",
+        duplicates="logical"
     ),
     prototype=prototype(
-        vars=NULL
+        vars=NULL,
+        duplicates=FALSE
     )
 )
 
 ##' @rdname VariableOrder
 ##' @export VariableGroup
-VariableGroup <- setClass("VariableGroup", representation=representation(
-    group="character",
-    entities="list"
-))
+VariableGroup <- setClass("VariableGroup",
+    representation=representation(
+        group="character",
+        entities="list",
+        duplicates="logical"
+    ),
+    prototype=prototype(
+        group="",
+        entities=list(),
+        duplicates=FALSE
+    )
+)
 
 ##' Collection of Variables within a Dataset
 ##'
@@ -123,6 +137,7 @@ VariableCatalog <- setClass("VariableCatalog", contains="ShojiCatalog",
     representation(order="VariableOrder"))
 DatasetCatalog <- setClass("DatasetCatalog", contains="ShojiCatalog")
 BatchCatalog <- setClass("BatchCatalog", contains="ShojiCatalog")
+PermissionCatalog <- setClass("PermissionCatalog", contains="ShojiCatalog")
 
 default.useAlias <- function () {
     opt <- getOption("crunch.useAlias")
