@@ -98,17 +98,17 @@ if (run.integration.tests) {
                 ## Temporary:
                 expect_error(ds$v4[is.na(ds$v2)] <- NA,
                     "Cannot update CategoricalVariable with type logical")
-                skip({
-                    expect_identical(length(categories(ds$v4)), 2L)
-                    try(ds$v4[is.na(ds$v2)] <- NA)
-                    expect_identical(length(categories(ds$v4)), 3L)
-                    expect_identical(as.vector(ds$v4),
-                        as.factor(c(rep(LETTERS[2:3], length=15), rep(NA, 5))))
-                    try(ds$v1[is.na(ds$v4)] <- NA)
-                    expect_identical(as.vector(ds$v1[is.na(ds$v4)]), 
-                        rep(NA_integer_, 5))
-                    expect_identical(sum(is.na(as.vector(ds$v1))), 10L)
-                }, "No Data isn't added, and is.na(ds$v4) returns 0 rows")
+                ## Because:
+                skip("No Data isn't added, and is.na(ds$v4) returns 0 rows")
+                expect_identical(length(categories(ds$v4)), 2L)
+                try(ds$v4[is.na(ds$v2)] <- NA)
+                expect_identical(length(categories(ds$v4)), 3L)
+                expect_identical(as.vector(ds$v4),
+                    as.factor(c(rep(LETTERS[2:3], length=15), rep(NA, 5))))
+                try(ds$v1[is.na(ds$v4)] <- NA)
+                expect_identical(as.vector(ds$v1[is.na(ds$v4)]), 
+                    rep(NA_integer_, 5))
+                expect_identical(sum(is.na(as.vector(ds$v1))), 10L)
             })
             
             test_that("reset test dataset", {
@@ -121,16 +121,15 @@ if (run.integration.tests) {
             test_that("Can 'mark missing'", {
                 expect_error(is.na(ds$v5) <- ds$v4 == "B",
                     "is.na<- not yet supported")
-                skip({
-                    try(is.na(ds$v3) <- ds$v3 >= 10 & ds$v3 < 13)
-                    expect_equivalent(as.vector(ds$v3),
-                        c(8, 9, rep(NA, 3), 13:27))
-                    try(is.na(ds$v5) <- ds$v4 == "B")
-                    expect_identical(sum(is.na(as.vector(ds$v5))), 10L)
-                    try(is.na(ds$v3) <- ds$v4 %in% "C")
-                    print(as.vector(ds$v3))
-                    expect_identical(sum(is.na(as.vector(ds$v3))), 10L)
-                }, "mark missing as function seems not to work")
+                skip("mark missing as function seems not to work")
+                try(is.na(ds$v3) <- ds$v3 >= 10 & ds$v3 < 13)
+                expect_equivalent(as.vector(ds$v3),
+                    c(8, 9, rep(NA, 3), 13:27))
+                try(is.na(ds$v5) <- ds$v4 == "B")
+                expect_identical(sum(is.na(as.vector(ds$v5))), 10L)
+                try(is.na(ds$v3) <- ds$v4 %in% "C")
+                print(as.vector(ds$v3))
+                expect_identical(sum(is.na(as.vector(ds$v3))), 10L)
             })
         })
         
